@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2005-2019 Centre National d'Etudes Spatiales (CNES)
+ * Copyright (C) 2005-2020 Centre National d'Etudes Spatiales (CNES)
  *
  * This file is part of Orfeo Toolbox
  *
@@ -21,8 +21,6 @@
 #ifndef otbOGRDriversInit_h
 #define otbOGRDriversInit_h
 
-#include <boost/noncopyable.hpp>
-
 #include "OTBGdalAdaptersExport.h"
 
 namespace otb
@@ -45,7 +43,7 @@ namespace ogr
  * VC++)
  * - Non-copyable
  */
-class OTBGdalAdapters_EXPORT Drivers : private boost::noncopyable
+class OTBGdalAdapters_EXPORT Drivers
 {
   /** \name Singleton related functions */
   //@{
@@ -59,6 +57,11 @@ private:
   Drivers();
   /** Destructor. */
   ~Drivers() = default;
+  
+  /** Non copyable class */
+  Drivers(const Drivers&) = delete;
+  Drivers& operator=(const Drivers&) = delete;
+
   //@}
 };
 }
