@@ -1,6 +1,6 @@
 /*
- * Copyright (C) 2005-2019 Centre National d'Etudes Spatiales (CNES)
- * Copyright (C) 2018 CS Systemes d'Information (CS SI)
+ * Copyright (C) 2005-2020 Centre National d'Etudes Spatiales (CNES)
+ * Copyright (C) 2018-2020 CS Systemes d'Information (CS SI)
  *
  * This file is part of Orfeo Toolbox
  *
@@ -116,6 +116,8 @@ GDALImageIO::GDALImageIO()
   m_ResolutionFactor  = 0;
   m_BytePerPixel      = 0;
   m_WriteRPCTags      = false;
+
+  m_epsgCode          = 0;
 }
 
 GDALImageIO::~GDALImageIO()
@@ -405,6 +407,11 @@ std::vector<std::string> GDALImageIO::GetOverviewsInfo()
   return desc;
 }
 
+void GDALImageIO::SetEpsgCode(const unsigned int epsgCode)
+{
+  m_epsgCode = epsgCode;
+}
+
 void GDALImageIO::InternalReadImageInformation()
 {
   itk::ExposeMetaData<unsigned int>(this->GetMetaDataDictionary(), MetaDataKey::ResolutionFactor, m_ResolutionFactor);
@@ -1165,6 +1172,13 @@ void GDALImageIO::Write(const void* buffer)
     lFirstColumn = 0;
   }
 
+  // If needed, set the coordinate reference
+  if (m_epsgCode != 0)
+  {
+    auto spatialReference = SpatialReference::FromEPSG(m_epsgCode);
+    m_Dataset->GetDataSet()->SetProjection(spatialReference.ToWkt().c_str());
+  }
+
   // Convert buffer from void * to unsigned char *
   // unsigned char *p = static_cast<unsigned char*>( const_cast<void *>(buffer));
   // printDataBuffer(p,  m_PxType->pixType, m_NbBands, 10*2); // Buffer incorrect
