@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2005-2019 Centre National d'Etudes Spatiales (CNES)
+ * Copyright (C) 2005-2020 Centre National d'Etudes Spatiales (CNES)
  *
  * This file is part of Orfeo Toolbox
  *
@@ -112,10 +112,10 @@ Mesh
 
   glVertexAttribPointer(
     id,
-    components,
+    static_cast<GLint>(components),
     m_VBO.GlType(),
     GL_FALSE,
-    m_VBO.Stride( components ),
+    static_cast<GLsizei>(m_VBO.Stride(components)),
     reinterpret_cast< GLvoid const * >( first * m_VBO.Size() )
     );
 
